; RENLAYERPTD2009.LSP - function to rename the ARC/INFO layer names to more
;    conventional alphanumeric descriptive text names.  Converts automatically
;    based on the current layer names.  If the layer names are in the ARC/INFO
;    format, the routine automatically detects it and  renames the layers to
;    the descriptive format and vice versa. Should only be used with 2009 PTD 
;    data model.
;
; written by: Thomas G. Tri          --   3/18/91
;             TRI COMPUTER SERVICES
;             4008 Hycliffe Ave.
;             Louisville, KY 40207
;
; modified by: Thomas G. Tri
;              SKEES ENGINEERING, INC.
;              4229 Bardstown Rd., Suite 314
;              Louisville, KY 40218
;
; modified by: Steven H. Baldock     --   10/3/97
;              SKEES ENGINEERING, INC.
;              4229 Bardstown Rd., Suite 314
;              Louisville, KY 40218
;
; modified by: Steven H. Baldock     --   3/11/98
;              SKEES ENGINEERING, INC.
;              4229 Bardstown Rd., Suite 314
;              Louisville, KY 40218
;
;modified by: Craig Sherer     --   9/16/03
;              SKEES ENGINEERING, INC.
;              400 Blankenbaker Pkwy, Ste 300
;              Louisville, KY 40243
;
;modified by: Jane Poole     -- 02/01/2011
;             LOJIC
;             Updated to 2009 PTD Data Model
;
;modified by:  Christian W. Miller, II  -- 05/17/2011
;              MSD
;              Updated to current MSD standard layer names


(defun c:renlayer(/ ce lyrlst nxtlyr mastlst lll i remain)
  (setq ce (getvar "cmdecho"))
  (setvar "cmdecho" 0)

  ; build list of layers defined in current drawing
  (setq lyrlst (list (dxf 2 (tblnext "layer" T))))
  (while (setq nxtlyr (tblnext "layer"))
    (setq lyrlst (append lyrlst (list (dxf 2 nxtlyr))))
  )

  ; build master layer list
  (setq mastlst
    (list
      "FIRM" "L-FLOOD"
      "AP01" "L-PVMT-AP-RUNWAY"
      "AP02" "L-PVMT-AP-TAXIWAY"
      "AP03" "L-PVMT-AP-UNPAVED"
      "BG01" "L-BLDG-PRIMARY"
      "BG02" "L-BLDG-SECONDARY"
      "BG03" "L-BLDG-SILO"
      "BG04" "L-BLDG-COURTYARD"
      "CN01" "L-CONT-MNR"
      "CN02" "L-CONT-MNR-DPR"
      "CN03" "L-CONT-MNR-OBSC"
      "CN04" "L-CONT-MNR-OBSC-DPR"
      "CN05" "L-CONT-MNR-BLDG"
      "CN06" "L-CONT-MNR-BLDG-DPR"
      "CN07" "L-CONT-MJR"
      "CN08" "L-CONT-MJR-BLDG"
      "CN09" "L-CONT-MJR-DPR"
      "CN10" "L-CONT-MJR-BLDG-DPR"
      "CN11" "L-CONT-MJR-OBSC"
      "CN12" "L-CONT-MJR-OBSC-DPR"
      "CN_ANNO_ELEV" "L-CONT-TX0"
      "HL01" "L-POND-LAKE"
      "HL02" "L-OHIO-RIVER"
      "HL03" "L-CREEK"
      "HL04" "L-SWAMP"
      "HL05" "L-DITCH"
      "HL06" "L-TOPO-ISLAND"
      "HL_ANNO" "L-POND-TX0"
      "MS01" "L-BLDG-PORCH"
      "MS02" "L-PVMT-LOADING"
      "MS03" "L-FENCE"
      "MS04" "L-TOPO-WALL"
      "MS05" "L-TOPO-DOCK"
      "MT01" "L-PVMT-PARKING"
      "MT02" "L-PVMT-PARKING-UNPAVED"
      "MT03" "L-DRIVE"
      "MT04" "L-DRIVE-UNPAVED"
      "MT05" "L-WALK"
      "MT06" "L-PVMT-HELIPAD"
      "MT07" "L-WALK-PEDWAY"
      "MT08" "L-PVMT-BRIDGE-FOOT"
      "PA_ANNO_PLATTED_DIMS"  "L-PL-PLAT-DIM-TX0"
      "PA_ANNO_DEEDED_ACREAGE"  "L-PL-DEED-ACR-TX0"
      "PA_ANNO_CONDO_NUMBER"  "L-PL-CONDO-TX0"
      "PA_ANNO_TAX_PARC_NUM" "L-PL-PARCELID-TX0"
      "PA_ANNO_SECONDARY_PARC_NUM" "L-PL-PARCELID2-TX0"
      "PA_ANNO_PLATTED_PARC_NUM" "L-PL-PLAT-PARCELID-TX0"
      "PA_ANNO_SUBLOT_NUM" "L-PL-SUBLOT-TX0"
      "PA_ANNO_BLOCK_NUM" "L-PL-BLOCK-TX0"
      "PA_ANNO_HISTORIC_BLOCK_NUM" "L-PL-HIST-BLOCK-TX0"
      "PA_ANNO_SUBDIV_BLOCK_ID" "L-PL-SUB-BLOCKID-TX0"
      "PA_ANNO_ROW_MEASUREMENT" "L-RW-DIM-TX0"
      "PA_ANNO_STREET_NAMES" "L-RW-TX0"
      "PA_ANNO_ALLEY_ROW_NOTATION" "L-RW-ALLEY-TX0"
      "PA_ANNO_SUB_NUM_SEC_NUM_BK_PG" "L-PL-SUB-SEC-BKPG-TX0"
      "PA_ANNO_MUNICIPALITY_NAME" "L-PL-MUNICIPALITY-TX0"
      "PA_ANNO_MISC_TEXT" "L-PL-MISC-TX0"
      "PA_ANNO_UNKNOWN_GRAPHICS_TEXT" "L-PL-UNKNOWN-GRAPHICS-TX0"
      "PA" "L-PL"
      "RD01" "L-PVMT"
      "RD02" "L-PVMT-UNPAVED"
      "RD03" "L-PVMT-ALLEY"
      "RD04" "L-PVMT-ALLEY-UNPAVED"
      "RD05" "L-PVMT-SHOULDER"
      "RD06" "L-PVMT-BRIDGE-VEHICLE"
      "RD07" "L-PVMT-MEDIAN"
      "RL01" "L-TOPO-REC-TENNIS"
      "RL02" "L-TOPO-REC-TRACK"
      "RL03" "L-TOPO-REC-BASEBALL"
      "RL04" "L-TOPO-REC-FOOTBALL"
      "RL05" "L-TOPO-REC-PLAYGROUND"
      "RL06" "L-TOPO-REC-PAVILN-BLCHR"
      "RL07" "L-TOPO-POOL-IG"
      "RL08" "L-TOPO-POOL-AG"
      "RL09" "L-TOPO-REC-GOLF"
      "RR_YARD" "L-RR-YARD-TX0"
      "RR_300" "L-RR-TX-300"
      "RR_ANNO" "L-RR-TX0"
      "RR01" "L-RR"
      "RR02" "L-RR-YARD"
      "RR03" "L-RR-ABANDONED"
      "RR04" "L-RR-YARD-ABANDONED"
      "RR05" "L-RR-BRIDGE"
      "STREETCL" "L-PVMT-CL"
      "STREETCL_ANNO_MAPBOOK" "L-PVMT-MAPBOOK-TX0"
      "STREETCL_ANNO_MJ100" "L-PVMT-TX-100"
      "STREETCL_ANNO_MJ250" "L-PVMT-TX-250"
      "STREETCL_ANNO_MJ400" "L-PVMT-TX-400"
      "STREETCL_ANNO_STREETCL" "L-PVMT-TX0"
      "SEWER" "L-SAN"
      "SEWERND" "L-SAN-MH"
      "SEWER_ANNO_NODEID" "L-SAN-MH-TX0"
      "SEWER_ANNO_DIA_TYPE" "L-SAN-DIA-TX0"
      "SEWER_ANNO_ASBUILT" "L-SAN-ASBUILT-TX0"
      "SH01" "L-SPOT"
      "SH02" "L-SPOT-WATER"
      "SH_ANNO_ELEV" "L-SPOT-TX0"
      "ADDSITE" "L-BLDG-TX0"
      "UP01" "L-U-ELEC-TRANSMISSION"
      "UP02" "L-U-ELEC-ANTENNA"
      "VL01" "L-VEG-TREELINE"
      "VP01" "L-VEG"
      "ZONING" "L-ZONING"
      "ZONING_ANNO_NAME" "L-ZONING-NAME-TX0"
      "ZONING_ANNO_TYPE" "L-ZONING-TYPE-TX0"
      "ZONING_ANNO_CODE" "L-ZONING-CODE-TX0"
      "FLD152" "L-FLOOD-A"
      "FLD153" "L-FLOOD-AE"
      "FLD160" "L-FLOOD-X"
      "FLD161" "L-FLOOD-X-OUTSIDE"
      "HYDRO260" "L-HYDRO-XSEC"
      "HYDRO261" "L-HYDRO-BASE-FLOOD"
      "HYDRO406" "L-HYDRO-DAM"
      "HYDRO418" "L-STM-CULVERT"
      "HYDRO435" "L-HYDRO-LEVEE"
      "HYDRO435W" "L-HYDRO-LEVEE-MLINE"
    )
  )

  (setq lll (length lyrlst))    ; lll - Length of Layer List
  (setq i 0)
  (while (< i lll)
    ;remain - remainder of list if layer is member of master list
    (if (setq remain (member (nth i lyrlst) mastlst))
      (progn
        (if (= (rem (length remain) 2) 0)
          (progn                ; converting from ARC/INFO to MSD names
            (command ".rename" "LA" (nth i lyrlst) (nth 1 remain))
          )
          ;else                 ; converting from MSD to ARC/INFO names
          (progn
            (command ".rename" "LA" (nth i lyrlst)
                  (nth (- (- (length mastlst) (length remain)) 1) mastlst))
          )
        )
      )
    )
    (setq i (1+ i))
  )

  (setvar "cmdecho" ce)
  (princ)
)


;* DXF takes an integer dxf code and an entity data list.
;* It returns the data element of the association pair.
;* from Inside AutoLISP by Smith & Gesner
(defun dxf (code elist)
    (cdr (assoc code elist))	;finds the association pair, strips 1st element
); defun

(princ) ;load cleanly
