; RENLAYER.LSP - function to rename the ARC/INFO layer names to more
;    conventional alphanumeric descriptive text names.  Converts automatically
;    based on the current layer names.  If the layer names are in the ARC/INFO
;    format, the routine automatically detects it and  renames the layers to
;    the descriptive format and vice versa.
;
; written by: Thomas G. Tri          --   3/18/91
;             TRI COMPUTER SERVICES
;             4008 Hycliffe Ave.
;             Louisville, KY 40207
;
; modified by: Thomas G. Tri
;              SKEES ENGINEERING, INC.
;              4229 Bardstown Rd., Suite 314
;              Louisville, KY 40218

; modified by: Steven H. Baldock     --   10/3/97
;              SKEES ENGINEERING, INC.
;              4229 Bardstown Rd., Suite 314
;              Louisville, KY 40218

; modified by: Steven H. Baldock     --   3/11/98
;              SKEES ENGINEERING, INC.
;              4229 Bardstown Rd., Suite 314
;              Louisville, KY 40218

;modified by: Craig Sherer     --   9/16/03
;              SKEES ENGINEERING, INC.
;              400 Blankenbaker Pkwy, Ste 300
;              Louisville, KY 40243



(defun c:renlayer(/ ce lyrlst nxtlyr mastlst lll i remain)
  (setq ce (getvar "cmdecho"))
  (setvar "cmdecho" 0)

  ; build list of layers defined in current drawing
  (setq lyrlst (list (dxf 2 (tblnext "layer" T))))
  (while (setq nxtlyr (tblnext "layer"))
    (setq lyrlst (append lyrlst (list (dxf 2 nxtlyr))))
  )

  ; build master layer list
  (setq mastlst
    (list
      "FIRM" "LO-FIRM-FEMA-FLOOD-BND"
      "AP01" "LO-AP-PAVE RUNW"
      "AP02" "LO-AP-UNPAVE TAXW"
      "AP03" "LO-AP-UNPAVE STRP"
      "AP99" "LO-AP-TILE-BND"
      "BG01" "LO-BG-PRIMARY"
      "BG02" "LO-BG-SECOND"
      "BG03" "LO-BG-RUIN"
      "BG04" "LO-BG-UNDER CONST"
      "BG05" "LO-BG-SILO"
      "BG06" "LO-BG-TANK"
      "BG07" "LO-BG-WTR TWR"
      "BG08" "LO-BG-COURTYD"
      "BG99" "LO-BG-TILE-BND"
      "CN01" "LO-CN-INT"
      "CN02" "LO-CN-INT-DPR"
      "CN03" "LO-CN-INT-OBSC"
      "CN04" "LO-CN-INT-OBSC-DPR"
      "CN05" "LO-CN-INT-BLDG"
      "CN06" "LO-CN-INT-BLDG-DPR"
      "CN07" "LO-CN-IDX"
      "CN08" "LO-CN-IDX-BLDG"
      "CN09" "LO-CN-IDX-DPR"
      "CN10" "LO-CN-IDX-BLDG-DPR"
      "CN11" "LO-CN-IDX-OBSC"
      "CN12" "LO-CN-IDX-OBSC-DPR"
      "CN13" "LO-CN-LBL-IDX"
      "CN14" "LO-CN-LBL-IDX-DPR"
      "CN15" "LO-CN-LBL-INT"
      "CN16" "LO-CN-LBL-INT-OBSC"
      "CN17" "LO-CN-LBL-INT-DPR"
      "CN18" "LO-CN-LBL-INT-OBSC-DPR"
      "CN99" "LO-CN-TILE-BND"
      "CN_ANNO_ELEV" "LO-CN-ANNO-TX"
      "DL01" "LO-DL-FLOODWALL"
      "DL01W" "LO-DL-FLOODWALL-MLINE"
      "DL02" "LO-DL-HEADWALL"
      "DL03" "LO-DL-PAVED-DITCH"
      "DL04" "LO-DL-CULVERT"
      "DL05" "LO-DL-CATCHBASIN-LINES"
      "DL99" "LO-DL-TILE-BND"
      "HL01" "LO-HL-LAKE-POND"
      "HL02" "LO-HL-OHIO-RIVER"
      "HL03" "LO-HL-SEWAGE-POND"
      "HL04" "LO-HL-RIV-STRM-LINE"
      "HL05" "LO-HL-SWAMP"
      "HL06" "LO-HL-FEAT-UND-STRUC"
      "HL07" "LO-HL-SING-LINE-HYDRO"
      "HL08" "LO-HL-ISLAND"
      "HL99" "LO-HL-TILE-BND"
      "HL_ANNO" "LO-HL-HYDROGRAPHY-TX"
      "MA01" "LO-MA-CEMETARY"
      "MA02" "LO-MA-JUNKYARD"
      "MA03" "LO-MA-STOCKPILE"
      "MA04" "LO-MA-QUARRY"
      "MA05" "LO-MA-CONST-AREA"
      "MA06" "LO-MA-SUBSTATION"
      "MA07" "LO-MA-TREATMENT-PLANT"
      "MA99" "LO-MA-TILE-BND"
      "MS01" "LO-MS-DECK-PORCH"
      "MS02" "LO-MS-UNATT-PAV-SLAB"
      "MS03" "LO-MS-HELIPAD"
      "MS04" "LO-MS-LOAD-DOCK"
      "MS05" "LO-MS-FENCE"
      "MS06" "LO-MS-WALL"
      "MS06W" "LO-MS-WALL-MLINE"
      "MS07" "LO-MS-DOCK-PIER"
      "MS08" "LO-MS-BOAT-RAMP"
      "MS09" "LO-MS-DAM"
      "MS10" "LO-MS-PIPE-CONVEYOR"
      "MS11" "LO-MS-BILLBRD-SIGN"
      "MS12" "LO-MS-GUARDRAIL"
      "MS13" "LO-MS-SMOKESTACK"
      "MS14" "LO-MS-PEDWAY"
      "MS99" "LO-MS-TILE-BND"
      "MT01" "LO-MT-PAVED-PKNG"
      "MT02" "LO-MT-UNPAVED-PKNG"
      "MT03" "LO-MT-PAVED-DWY"
      "MT04" "LO-MT-UNPVD-DWY"
      "MT05" "LO-MT-PED-AREA"
      "MT99" "LO-MT-TILE-BND"
      "PA_ANNO_PLATTED_DIMS"  "LO-PA-PLAT-DIM-TX"
      "PA_ANNO_DEEDED_ACREAGE"  "LO-PA-DEED-ACR-TX"
      "PA_ANNO_CONDO_NUMBER"  "LO-PA-CONDO-TX"
      "PA_ANNO_TAX_PARC_NUM" "LO-PA-PARCELID-TX"
      "PA_ANNO_SECONDARY_PARC_NUM" "LO-PA-2ND-PARCELID-TX"
      "PA_ANNO_PLATTED_PARC_NUM" "LO-PA-PLAT-PARCELID-TX"
      "PA_ANNO_SUBLOT_NUM" "LO-PA-SUBLOT-TX"
      "PA_ANNO_BLOCK_NUM" "LO-PA-BLOCK-TX"
      "PA_ANNO_HISTORIC_BLOCK_NUM" "LO-PA-HIST-BLOCK-TX"
      "PA_ANNO_SUBDIV_BLOCK_ID" "LO-PA-SUB-BLOCK-ID-TX"
      "PA_ANNO_ROW_MEASUREMENT" "LO-PA-ROW-TX"
      "PA_ANNO_STREET_NAMES" "LO-PA-STR-NAM"
      "PA_ANNO_ALLEY_ROW_NOTATION" "LO-PA-ALLEY-ROW-TX"
      "PA_ANNO_SUB_NUM_SEC_NUM_BK_PG" "LO-PA-SUB-SEC-BKPG-TX"
      "PA_ANNO_MUNICIPALITY_NAME" "LO-PA-MUNICIPALITY-NAME-TX"
      "PA_ANNO_MISC_TEXT" "LO-PA-MISC-TX"
      "PA_ANNO_UNKNOWN_GRAPHICS_TEXT" "LO-PA-UNKNOWN-GRAPHICS-TX"
      "PA_ANNO_UNKNOWN" "LO-PA-UNKNOWN-TX"
      "PA"  "LO-PA-PROPERTY"
      "RD01" "LO-RD-PAVED-ROAD"
      "RD02" "LO-RD-UNPAVED-ROAD"
      "RD03" "LO-RD-ALLEY-PVD"
      "RD04" "LO-RD-ALLEY-UNPVD"
      "RD05" "LO-RD-SHOULDER-IMP"
      "RD06" "LO-RD-VEHICLE-BRIDGE"
      "RD07" "LO-RD-FOOT-BRIDGE"
      "RD08" "LO-RD-TRAIL"
      "RD09" "LO-RD-MEDIAN"
      "RD99" "LO-RD-TILE-BND"
      "RL01" "LO-RL-TENNIS"
      "RL02" "LO-RL-SPORTS-TRACK"
      "RL03" "LO-RL-BALLFIELD"
      "RL04" "LO-RL-FOOTBALL"
      "RL05" "LO-RL-PLAYGROUND"
      "RL06" "LO-RL-PAVILN-BLCHER"
      "RL07" "LO-RL-IN-GND-POOL"
      "RL08" "LO-RL-UP-GND-POOL"
      "RL09" "LO-RL-GOLF-COURSE"
      "RL99" "LO-RL-TILE-BND"
      "1RR" "LO-RR-TX"
      "RR_YARD" "LO-RR-YARDS-TX"
      "RR_300" "LO-RR-300-SCALE-TX"
      "RR_ANNO" "LO-RR-ANNO-TX"
      "RR01" "LO-RR"
      "RR02" "LO-RR-SPUR"
      "RR03" "LO-RR-ABANDONED"
      "RR04" "LO-RR-ABANDONED-SPUR"
      "RR05" "LO-RR-BRIDGE"
      "RR99" "LO-RR-TILE-BND"
      "STREETCL" "LO-STREETCL-CENTERLINE"
      "STREETCL_ANNO_MAPBOOK" "LO-STREET-MAPBOOK-TX"
      "STREETCL_ANNO_MJ100" "LO-STREET-100SCALE-TX"
      "STREETCL_ANNO_MJ250" "LO-STREET-250SCALE-TX"
      "STREETCL_ANNO_MJ400" "LO-STREET-400SCALE-TX"
      "STREETCL_ANNO_STREETCL" "LO-STREETS-TX"
      "SEWER" "LO-SEWER-LINE"
      "SEWERND" "LO-SEWER-NODE"
      "SEWER_ANNO_NODEID" "LO-SEWERANNO-NODE-ID-TX"
      "SEWER_ANNO_DIA_TYPE" "LO-SEWERANNO-DIA-TYPE-TX"
      "SEWER_ANNO_ASBUILT" "LO-SEWERANNO-ASBUILT-TX"
      "SEWER_ANNO_UNKNOWN" "LO-SEWERANNO_UNKNOWN-TX"
      "SH01" "LO-SH-SPOT-LAND"
      "SH02" "LO-SH-SPOT-WATER"
      "SH_ANNO_ELEV" "LO-SH-SPOT-ELEV-TX"
      "SITEADD_ANNO_HOUSENO" "LO-SITEADD-ADDRESS-TX"
      "TP" "LO-TP-TINPOINT"
      "TR01" "LO-TR-TRAIL"
      "TR99" "LO-TR-TILE-BND"
      "UL01" "LO-UL-TRANSMISSION-LINES"
      "UL02" "LO-UL-PIPELINES"
      "UL99" "LO-UL-TILE-BND"
      "UP01" "LO-UP-POLE-LIGHT"
      "UP02" "LO-UP-POLE-OTHER"
      "UP03" "LO-UP-POLE-TRANSMISSION"
      "UP04" "LO-UP-POLE-UTILITY"
      "UP05" "LO-UP-POLE-TRANSMISSION-TWR"
      "UP06" "LO-UP-FIRE-HYDRANT"
      "UP07" "LO-UP-CATCH-BASIN"
      "UP08" "LO-UP-MANHOLE"
      "UP09" "LO-UP-ANTENNA"
      "VL01" "LO-VL-BRUSH-AREA"
      "VL02" "LO-VL-TREE-AREA"
      "VL99" "LO-VL-TILE-BND"
      "VP01" "LO-VP-TREE"
      "ZONING" "LO-ZONING-LINE"
      "ZONING_ANNO_NAME" "LO-ZONING-NAME-TX"
      "ZONING_ANNO_TYPE" "LO-ZONING-TYPE-TX"
      "ZONING_ANNO_CODE" "LO-ZONING-CODE-TX"
      "UNKNOWN" "LO-UNKNOWN"
      "TL01" "LO-TL-HARD-BREAKLINE"
      "TL02" "LO-TL-SOFT-BREAKLINE"
      "TL99" "LO-TL-TILE-BND"
      "FLD152" "LO-FLD-ZONE-A"
      "FLD153" "LO-FLD-ZONE-AE"
      "FLD160" "LO-FLD-ZONE-X-INSIDE"
      "FLD161" "LO-FLD-ZONE-X-OUTSIDE"
      "HYDRO260" "LO-HYDRO-CROSS-SEC"
      "HYDRO261" "LO-HYDRO-BASE-FLD-ELEV"
      "HYDRO406" "LO-HYDRO-DAM"
      "HYDRO418" "LO-HYDRO-CULVERT"
      "HYDRO435" "LO-HYDRO-LEVEE"
      "HYDRO435W" "LO-HYDRO-LEVEE-MLINE"
    )
  )

  (setq lll (length lyrlst))    ; lll - Length of Layer List
  (setq i 0)
  (while (< i lll)
    ;remain - remainder of list if layer is member of master list
    (if (setq remain (member (nth i lyrlst) mastlst))
      (progn
        (if (= (rem (length remain) 2) 0)
          (progn                ; converting from ARC/INFO to MSD names
            (command ".rename" "LA" (nth i lyrlst) (nth 1 remain))
          )
          ;else                 ; converting from MSD to ARC/INFO names
          (progn
            (command ".rename" "LA" (nth i lyrlst)
                  (nth (- (- (length mastlst) (length remain)) 1) mastlst))
          )
        )
      )
    )
    (setq i (1+ i))
  )

  (setvar "cmdecho" ce)
  (princ)
)


;* DXF takes an integer dxf code and an entity data list.
;* It returns the data element of the association pair.
;* from Inside AutoLISP by Smith & Gesner
(defun dxf (code elist)
    (cdr (assoc code elist))	;finds the association pair, strips 1st element
); defun

(princ) ;load cleanly
